import java.io.Serializable;
import java.util.HashMap;
import java.util.UUID;

public class StockLocation implements Serializable {
    private static final long serialVersionUID = 1L;
    private UUID id;
    private String name;
    private String description;
    private String address;
    private String city;
    private String country;

    private String postalCode;

    private HashMap<String, Integer> stockItems = new HashMap<>();

    public StockLocation(String name, String description, String address, String city, String country, String postalCode)
    {
        this.id = UUID.randomUUID();

        this.name = name;
        this.description = description;
        this.address = address;
        this.city = city;
        this.country = country;
        this.postalCode = postalCode;
    }

    public StockLocation(UUID id, String name, String description, String address, String city, String country, String postalCode)
    {
        this.id = id;
        this.name = name;
        this.description = description;
        this.address = address;
        this.city = city;
        this.country = country;
        this.postalCode = postalCode;
    }

    public String getDescription() {
        return description;
    }

    public UUID getId() {
        return id;
    }

    public String getName() {
        return name;
    }

    public String getAddress() {
        return address;
    }

    public String getCity() {
        return city;
    }

    public String getCountry() {
        return country;
    }

    public String getPostalCode() {
        return postalCode;
    }

    public int getQuantity(StockItem item) {
        return stockItems.getOrDefault(item.getSKU(), 0);
    }

    public void addStockItem(StockItem item, int quantity) {
        if (stockItems.containsKey(item.getSKU())) {
            stockItems.put(item.getSKU(), stockItems.get(item.getSKU()) + quantity);
        } else {
            stockItems.put(item.getSKU(), quantity);
        }
    }

    public boolean removeStockItem(StockItem item, int quantity) {
        if (stockItems.containsKey(item.getSKU())) {
            int currentQuantity = stockItems.get(item.getSKU());
            if (currentQuantity > quantity) {
                stockItems.put(item.getSKU(), currentQuantity - quantity);
                return true;
            }
        }
        return false;
    }

    public boolean transferStockItem(StockLocation destination, StockItem item, int quantity) {
        if (stockItems.containsKey(item.getSKU()) && stockItems.get(item.getSKU()) >= quantity) {
            removeStockItem(item, quantity);
            destination.addStockItem(item, quantity);
            return true;
        }
        return false;
    }
}
